@@ -13,6 +13,7 @@
 
 #include <QAbstractListModel>
 #include <QSortFilterProxyModel>
+#include <qmimetype.h>
 
 namespace Ui
 {
@@ -58,6 +59,9 @@ public:
     void setShowOnlyPrefferedApps(bool show);
     bool showOnlyPreferredApps() const;
 
+    void setDefaultApp(const QString &);
+    QString defaultApp() const;
+
     void setFilter(const QString &text);
     QString filter() const;
 
@@ -72,6 +76,7 @@ protected:
 private:
     bool m_showOnlyPreferredApps = true;
     QString m_filter;
+    QString m_defaultApp;
 };
 
 class AppChooserData : public QObject
@@ -79,6 +84,8 @@ class AppChooserData : public QObject
     Q_OBJECT
     Q_PROPERTY(QString fileName READ fileName WRITE setFileName NOTIFY fileNameChanged)
     Q_PROPERTY(QString defaultApp READ defaultApp WRITE setDefaultApp NOTIFY defaultAppChanged)
+    Q_PROPERTY(QString mimeName READ mimeName WRITE setMimeName NOTIFY mimeNameChanged)
+    Q_PROPERTY(QString mimeDesc READ mimeDesc NOTIFY mimeDescChanged)
 
 public:
     AppChooserData(QObject *parent = nullptr);
@@ -91,12 +98,21 @@ public:
     void setDefaultApp(const QString &defaultApp);
     Q_SIGNAL void defaultAppChanged();
 
-    Q_SIGNAL void applicationSelected(const QString &desktopFile);
+    QString mimeName() const;
+    void setMimeName(const QString &mimeName);
+    Q_SIGNAL void mimeNameChanged();
+
+    QString mimeDesc() const;
+    void setMimeDesc(const QString &mimeDesc);
+    Q_SIGNAL void mimeDescChanged();
+
+    Q_SIGNAL void applicationSelected(const QString &desktopFile, bool remember = false);
     Q_SIGNAL void openDiscover();
 
 private:
     QString m_defaultApp;
     QString m_fileName;
+    QString m_mimeName;
 };
 
 class AppModel : public QAbstractListModel
@@ -144,13 +160,13 @@ public:
 
     QString selectedApplication() const;
 private Q_SLOTS:
-    void onApplicationSelected(const QString &desktopFile);
+    void onApplicationSelected(const QString &desktopFile, const bool remember = false);
     void onOpenDiscover();
 
 private:
     AppModel *const m_model;
     QString m_selectedApplication;
-    const QString m_mimeName;
+    AppChooserData *const m_appChooserData;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_APPCHOOSER_DIALOG_H
