@@ -22,14 +22,9 @@ class RemoteDesktopDialog : public QuickDialog
 {
     Q_OBJECT
 public:
-    RemoteDesktopDialog(const QString &appName,
-                        RemoteDesktopPortal::DeviceTypes deviceTypes,
-                        bool screenSharingEnabled = false,
-                        bool multiple = false,
-                        QObject *parent = nullptr);
+    RemoteDesktopDialog(const QString &appName, RemoteDesktopPortal::DeviceTypes deviceTypes, bool screenSharingEnabled, QObject *parent = nullptr);
 
-    QList<Output> selectedOutputs() const;
-    RemoteDesktopPortal::DeviceTypes deviceTypes() const;
+    static QString buildDescription(const QString &appName, RemoteDesktopPortal::DeviceTypes deviceTypes, bool screenSharingEnabled);
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_REMOTEDESKTOP_DIALOG_H
