@@ -7,6 +7,7 @@
 #pragma once
 
 #include <QObject>
+#include <QScreen>
 #include <QSharedPointer>
 #include <QVector>
 #include <optional>
@@ -34,6 +35,7 @@ public:
     ~ScreencastingStream() override;
 
     quint32 nodeid() const;
+    QRect geometry() const;
 
 Q_SIGNALS:
     void created(quint32 nodeid);
@@ -61,6 +63,7 @@ public:
     Q_ENUM(CursorMode)
 
     ScreencastingStream *createOutputStream(KWayland::Client::Output *output, CursorMode mode);
+    ScreencastingStream *createOutputStream(QScreen *screen, CursorMode mode);
     ScreencastingStream *createWindowStream(const QString &uuid, CursorMode mode);
     ScreencastingStream *createRegionStream(const QRect &geometry, qreal scale, CursorMode mode);
     ScreencastingStream *createVirtualOutputStream(const QString &name, const QSize &size, qreal scale, CursorMode mode);
