@@ -21,6 +21,35 @@
 #include "dbushelpers.h"
 #include <KConfigCore/KConfigGroup>
 
+/* accent-color */
+struct AccentColorArray {
+    double r = 0.0; // 0-1
+    double g = 0.0; // 0-1
+    double b = 0.0; // 0-1
+
+    operator QVariant() const
+    {
+        return QVariant::fromValue(*this);
+    }
+};
+Q_DECLARE_METATYPE(AccentColorArray)
+
+QDBusArgument &operator<<(QDBusArgument &argument, const AccentColorArray &item)
+{
+    argument.beginStructure();
+    argument << item.r << item.g << item.b;
+    argument.endStructure();
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, AccentColorArray &item)
+{
+    argument.beginStructure();
+    argument >> item.r >> item.g >> item.b;
+    argument.endStructure();
+    return argument;
+}
+
 static bool groupMatches(const QString &group, const QStringList &patterns)
 {
     for (const QString &pattern : patterns) {
@@ -44,6 +73,7 @@ SettingsPortal::SettingsPortal(QObject *parent)
     : QDBusAbstractAdaptor(parent)
 {
     qDBusRegisterMetaType<VariantMapMap>();
+    qDBusRegisterMetaType<AccentColorArray>();
 
     m_kdeglobals = KSharedConfig::openConfig();
 
@@ -93,6 +123,7 @@ void SettingsPortal::ReadAll(const QStringList &groups)
     if (groupMatches(QStringLiteral("org.freedesktop.appearance"), groups)) {
         QVariantMap appearanceSettings;
         appearanceSettings.insert(QStringLiteral("color-scheme"), readFdoColorScheme().variant());
+        appearanceSettings.insert(QStringLiteral("accent-color"), readAccentColor().variant());
 
         result.insert(QStringLiteral("org.freedesktop.appearance"), appearanceSettings);
     }
@@ -148,10 +179,16 @@ void SettingsPortal::Read(const QString &group, const QString &key)
     QDBusMessage reply;
     QDBusMessage message = q_ptr->message();
 
-    if (group == QLatin1String("org.freedesktop.appearance") && key == QLatin1String("color-scheme")) {
-        reply = message.createReply(QVariant::fromValue(readFdoColorScheme()));
-        QDBusConnection::sessionBus().send(reply);
-        return;
+    if (group == QLatin1String("org.freedesktop.appearance")) {
+        if (key == QLatin1String("color-scheme")) {
+            reply = message.createReply(QVariant::fromValue(readFdoColorScheme()));
+            QDBusConnection::sessionBus().send(reply);
+            return;
+        } else if (key == QLatin1String("accent-color")) {
+            reply = message.createReply(QVariant::fromValue(readAccentColor()));
+            QDBusConnection::sessionBus().send(reply);
+            return;
+        }
     }
     // All other namespaces start with this prefix
     else if (!group.startsWith(QStringLiteral("org.kde.kdeglobals"))) {
@@ -192,6 +229,9 @@ void SettingsPortal::globalSettingChanged(int type, int arg)
                               readProperty(QStringLiteral("org.kde.kdeglobals.General"), QStringLiteral("ColorScheme")));
 
         Q_EMIT SettingChanged(QStringLiteral("org.freedesktop.appearance"), QStringLiteral("color-scheme"), readFdoColorScheme());
+
+        // https://github.com/flatpak/xdg-desktop-portal/pull/815
+        Q_EMIT SettingChanged(QStringLiteral("org.freedesktop.appearance"), QStringLiteral("accent-color"), readAccentColor());
         break;
     case FontChanged:
         fontChanged();
@@ -270,3 +310,9 @@ QDBusVariant SettingsPortal::readFdoColorScheme()
 
     return QDBusVariant(result);
 }
+
+QDBusVariant SettingsPortal::readAccentColor() const
+{
+    const QColor accentColor = qGuiApp->palette().highlight().color();
+    return QDBusVariant(AccentColorArray{accentColor.redF(), accentColor.greenF(), accentColor.blueF()});
+}
