@@ -115,6 +115,11 @@ WaylandIntegration::Stream WaylandIntegration::startStreamingOutput(quint32 outp
     return globalWaylandIntegration->startStreamingOutput(outputName, mode);
 }
 
+WaylandIntegration::Stream WaylandIntegration::startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode)
+{
+    return globalWaylandIntegration->startStreamingOutput(screen, mode);
+}
+
 WaylandIntegration::Stream WaylandIntegration::startStreamingWorkspace(Screencasting::CursorMode mode)
 {
     return globalWaylandIntegration->startStreamingWorkspace(mode);
@@ -150,9 +155,9 @@ void WaylandIntegration::requestPointerMotion(const QSizeF &delta)
     globalWaylandIntegration->requestPointerMotion(delta);
 }
 
-void WaylandIntegration::requestPointerMotionAbsolute(const QPointF &pos)
+void WaylandIntegration::requestPointerMotionAbsolute(uint stream, const QPointF &pos)
 {
-    globalWaylandIntegration->requestPointerMotionAbsolute(pos);
+    globalWaylandIntegration->requestPointerMotionAbsolute(stream, pos);
 }
 
 void WaylandIntegration::requestPointerAxisDiscrete(Qt::Orientation axis, qreal delta)
@@ -290,10 +295,28 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
         notification->sendEvent();
         return {};
     }
-    m_streamedScreenPosition = output->globalPosition();
     return startStreaming(m_screencasting->createOutputStream(output.data(), mode),
                           {
-                              {QLatin1String("size"), output->pixelSize()},
+                              {QLatin1String("size"), output->geometry().size()},
+                              {QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Monitor)},
+                          });
+}
+
+WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode)
+{
+    auto stream = m_screencasting->createOutputStream(screen, mode);
+    if (!stream) {
+        qCWarning(XdgDesktopPortalKdeWaylandIntegration) << "Cannot stream, output not found" << screen->name();
+        auto notification = new KNotification(QStringLiteral("screencastfailure"), KNotification::CloseOnTimeout);
+        notification->setTitle(i18n("Failed to start screencasting"));
+        notification->setIconName(QStringLiteral("dialog-error"));
+        notification->sendEvent();
+        return {};
+    }
+
+    return startStreaming(stream,
+                          {
+                              {QLatin1String("size"), screen->size()},
                               {QLatin1String("source_type"), static_cast<uint>(ScreenCastPortal::Monitor)},
                           });
 }
@@ -305,7 +328,6 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
     for (QScreen *screen : screens) {
         workspace |= screen->geometry();
     }
-    m_streamedScreenPosition = workspace.topLeft();
     return startStreaming(m_screencasting->createRegionStream(workspace, 1, mode),
                           {
                               {QLatin1String("size"), workspace.size()},
@@ -349,7 +371,6 @@ WaylandIntegration::Stream WaylandIntegration::WaylandIntegrationPrivate::startS
             stopStreaming(nodeid);
         });
         Q_ASSERT(ret.isValid());
-        qDebug() << "start streaming" << ret << m_streamedScreenPosition;
 
         loop.quit();
     });
@@ -395,10 +416,17 @@ void WaylandIntegration::WaylandIntegrationPrivate::requestPointerMotion(const Q
     }
 }
 
-void WaylandIntegration::WaylandIntegrationPrivate::requestPointerMotionAbsolute(const QPointF &pos)
+void WaylandIntegration::WaylandIntegrationPrivate::requestPointerMotionAbsolute(uint streamNodeId, const QPointF &pos)
 {
     if (m_streamInput && m_fakeInput) {
-        m_fakeInput->requestPointerMoveAbsolute(pos + m_streamedScreenPosition);
+        for (auto stream : std::as_const(m_streams)) {
+            if (stream.nodeId == streamNodeId) {
+                m_fakeInput->requestPointerMoveAbsolute(pos + stream.stream->geometry().topLeft());
+                return;
+            }
+        }
+        // If no stream is found, just send it as absolute coordinates relative to the workspace.
+        m_fakeInput->requestPointerMoveAbsolute(pos);
     }
 }
 
