@@ -12,6 +12,7 @@
 #include <QDBusArgument>
 #include <QObject>
 #include <QPoint>
+#include <QScreen>
 #include <QSize>
 #include <QVariant>
 
@@ -128,6 +129,7 @@ bool isStreamingAvailable();
 
 void acquireStreamingInput(bool acquire);
 Stream startStreamingOutput(quint32 outputName, Screencasting::CursorMode mode);
+Stream startStreamingOutput(QScreen *screen, Screencasting::CursorMode mode);
 Stream startStreamingWorkspace(Screencasting::CursorMode mode);
 Stream startStreamingVirtual(const QString &name, const QSize &size, Screencasting::CursorMode mode);
 Stream startStreamingWindow(const QMap<int, QVariant> &win, Screencasting::CursorMode mode);
@@ -136,7 +138,7 @@ void stopStreaming(uint node);
 void requestPointerButtonPress(quint32 linuxButton);
 void requestPointerButtonRelease(quint32 linuxButton);
 void requestPointerMotion(const QSizeF &delta);
-void requestPointerMotionAbsolute(const QPointF &pos);
+void requestPointerMotionAbsolute(uint stream, const QPointF &pos);
 void requestPointerAxis(qreal x, qreal y);
 void requestPointerAxisDiscrete(Qt::Orientation axis, qreal delta);
 
